{
	"name" : "Localisation for Quebec",
	"version" : "1.0",
	"author" : "Tiny",
	"category" : "Localisation/Account charts",
	"depends" : ["base", "account"],
	"init_xml" : [],
	"demo_xml" : ["account_demo.xml"],
	"update_xml" : ["account_pc_canada.xml"],
	"active": False,
	"installable": True
}
